[svn:parrot] r40644 - in branches/pmc_sans_unionval: docs/pdds src/gc

whiteknight at svn.parrot.org whiteknight at svn.parrot.org
Tue Aug 18 23:48:01 UTC 2009


Author: whiteknight
Date: Tue Aug 18 23:48:00 2009
New Revision: 40644
URL: https://trac.parrot.org/parrot/changeset/40644

Log:
[pmc_sans_unionval] remove all references to the now-unused buffer_header_pool

Modified:
   branches/pmc_sans_unionval/docs/pdds/pdd09_gc.pod
   branches/pmc_sans_unionval/src/gc/gc_private.h
   branches/pmc_sans_unionval/src/gc/mark_sweep.c

Modified: branches/pmc_sans_unionval/docs/pdds/pdd09_gc.pod
==============================================================================
--- branches/pmc_sans_unionval/docs/pdds/pdd09_gc.pod	Tue Aug 18 22:57:11 2009	(r40643)
+++ branches/pmc_sans_unionval/docs/pdds/pdd09_gc.pod	Tue Aug 18 23:48:00 2009	(r40644)
@@ -299,8 +299,7 @@
 The Arenas structure contains pointers to a variety of memory pools, each used
 for a specific purpose. Two are Memory_Pool pointers (memory_pool,
 constant_string_pool), and six are Small_Object_Pool structures (pmc_pool,
-pmc_ext_pool, constant_pmc_pool, buffer_header_pool,
-constant_string_header_pool).
+constant_pmc_pool, constant_string_header_pool).
 
 The Arenas structure holds function pointers for the core defined interface of
 the currently active GC subsystem: C<init_pool>, C<do_gc_mark>,

Modified: branches/pmc_sans_unionval/src/gc/gc_private.h
==============================================================================
--- branches/pmc_sans_unionval/src/gc/gc_private.h	Tue Aug 18 22:57:11 2009	(r40643)
+++ branches/pmc_sans_unionval/src/gc/gc_private.h	Tue Aug 18 23:48:00 2009	(r40644)
@@ -185,7 +185,6 @@
     struct Small_Object_Pool *string_header_pool;
     struct Small_Object_Pool *pmc_pool;
     struct Small_Object_Pool *constant_pmc_pool;
-/*   struct Small_Object_Pool *buffer_header_pool; */
     struct Small_Object_Pool *constant_string_header_pool;
     struct Small_Object_Pool **sized_header_pools;
     size_t num_sized;

Modified: branches/pmc_sans_unionval/src/gc/mark_sweep.c
==============================================================================
--- branches/pmc_sans_unionval/src/gc/mark_sweep.c	Tue Aug 18 22:57:11 2009	(r40643)
+++ branches/pmc_sans_unionval/src/gc/mark_sweep.c	Tue Aug 18 23:48:00 2009	(r40644)
@@ -1018,7 +1018,7 @@
 pools for string headers, constant string headers, buffers, PMCs, PMC_EXTs, and
 constant PMCs.
 
-The C<string_header_pool> and C<buffer_header_pool> are actually both in the
+The C<string_header_pool> actually lives in the
 sized pools, although no other sized pools are created here.
 
 =cut
@@ -1037,11 +1037,9 @@
 
     /* Init the buffer header pool
      *
      * The buffer_header_pool and the string_header_pool actually live in the
      * sized_header_pools. These pool pointers only provide faster access in
      * new_*_header */
-    /* arena_base->buffer_header_pool       = new_buffer_pool(interp);
-       arena_base->buffer_header_pool->name = "buffer_header"; */
 
     /* Init the string header pool */
     arena_base->string_header_pool       = new_string_pool(interp, 0);
@@ -1037,11 +1037,9 @@
     /* Init the buffer header pool
      *
-     * The buffer_header_pool and the string_header_pool actually live in the
+     * The string_header_pool actually lives in the
      * sized_header_pools. These pool pointers only provide faster access in
      * new_*_header */


More information about the parrot-commits mailing list